@@ -23,6 +23,8 @@
 #include "filestorage.h"
 #include "memorycalendar.h"
 
+#include "setuptzinfo.h"
+
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <kcomponentdata.h>
@@ -30,10 +32,10 @@
 #include <ksystemtimezone.h>
 #include <KLocalizedString>
 
-#include <QtCore/QFile>
-#include <QtCore/QTextStream>
-#include <QtCore/QCoreApplication>
-#include <QtCore/QCommandLineParser>
+#include <QFile>
+#include <QTextStream>
+#include <QCoreApplication>
+#include <QCommandLineParser>
 
 using namespace KCalCore;
 
@@ -64,6 +66,7 @@ int main(int argc, char **argv)
     if (parsedArgs.isEmpty()) {
         parser.showHelp();
     }
+    const SetupTzinfo setup;
     QString input = parsedArgs[0];
     qDebug() << "Input file:" << input;
 
